<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
$plugin = OW::getPluginManager()->getPlugin('blogs');

$key = strtoupper($plugin->getKey());

OW::getAutoloader()->addClass('Post', $plugin->getBolDir() . 'dto' . DS . 'post.php');
OW::getAutoloader()->addClass('PostDao', $plugin->getBolDir() . 'dao' . DS . 'post_dao.php');
OW::getAutoloader()->addClass('PostService', $plugin->getBolDir() . 'service' . DS . 'post_service.php');


OW::getRouter()->addRoute(new OW_Route('blogs-uninstall', 'admin/blogs/uninstall', 'BLOGS_CTRL_Admin', 'uninstall'));

OW::getRouter()->addRoute(new OW_Route('blogs', 'blogs', "{$key}_CTRL_Blog", 'index'));

OW::getRouter()->addRoute(new OW_Route('post-save-new', 'blogs/post/new', "{$key}_CTRL_Save", 'index'));
OW::getRouter()->addRoute(new OW_Route('post-save-edit', 'blogs/post/edit/:id', "{$key}_CTRL_Save", 'index'));

OW::getRouter()->addRoute(new OW_Route('post', 'blogs/post/:id', "{$key}_CTRL_View", 'index'));

OW::getRouter()->addRoute(new OW_Route('post-part', 'blogs/post/:id/:part', "{$key}_CTRL_View", 'index'));

OW::getRouter()->addRoute(new OW_Route('user-blog', 'blogs/user/:user', "{$key}_CTRL_UserBlog", 'index'));

OW::getRouter()->addRoute(new OW_Route('user-post', 'blogs/:id', "{$key}_CTRL_View", 'index'));

OW::getRouter()->addRoute(new OW_Route('blog-latest', 'blogs/latest', "{$key}_CTRL_Blog", 'index'));
OW::getRouter()->addRoute(new OW_Route('blog-most-discussed', 'blogs/most-discussed', "{$key}_CTRL_Blog", 'index'));
OW::getRouter()->addRoute(new OW_Route('blog-top-rated', 'blogs/top-rated', "{$key}_CTRL_Blog", 'index'));
OW::getRouter()->addRoute(new OW_Route('blog-by-tag', 'blogs/browse-by-tag/', "{$key}_CTRL_Blog", 'index'));

OW::getRouter()->addRoute(new OW_Route('blog-manage-posts', 'blogs/my-published-posts/', "{$key}_CTRL_ManagementPost", 'index'));
OW::getRouter()->addRoute(new OW_Route('blog-manage-drafts', 'blogs/my-drafts/', "{$key}_CTRL_ManagementPost", 'index'));
OW::getRouter()->addRoute(new OW_Route('blog-manage-comments', 'blogs/my-incoming-comments/', "{$key}_CTRL_ManagementComment", 'index'));

OW::getRouter()->addRoute(new OW_Route('blogs-admin', 'admin/blogs', "{$key}_CTRL_Admin", 'index'));

OW::getRegistry()->addToArray(BASE_CMP_AddNewContent::REGISTRY_DATA_KEY,
    array(
        BASE_CMP_AddNewContent::DATA_KEY_ICON_CLASS => 'ow_ic_write',
        BASE_CMP_AddNewContent::DATA_KEY_URL => OW::getRouter()->urlForRoute('post-save-new'),
        BASE_CMP_AddNewContent::DATA_KEY_LABEL => OW::getLanguage()->text($plugin->getKey(), 'add_new_link')
    )
);

OW::getEventManager()->bind(OW_EventManager::ON_USER_SUSPEND, array(PostService::getInstance(), 'onAuthorSuspend'));

function blogs_on_notify_actions( BASE_EventCollector $e )
{
    $e->add(array(
        'section' => 'blogs',
        'action' => 'blogs-add_comment',
        'description' => OW::getLanguage()->text('blogs', 'email_notifications_setting_comment'),
        'selected' => true,
        'sectionLabel' => 'Blogs',
        'sectionIcon' => 'ow_ic_write'
    ));
}
OW::getEventManager()->bind('base.notify_actions', 'blogs_on_notify_actions');

function blogs_on_notify( OW_Event $event )
{
    $params = $event->getParams();

    if ( empty($params['entityType']) || $params['entityType'] !== 'blog-post' )
        return;

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = $params['commentId'];

    $postService = PostService::getInstance();

    $post = $postService->findById($entityId);

    $title = $post->getTitle();

    $actor = array(
        'name' => BOL_UserService::getInstance()->getDisplayName($userId),
        'url' => BOL_UserService::getInstance()->getUserUrl($userId)
    );

    $ownerId = $post->getAuthorId();

    $comment = BOL_CommentService::getInstance()->findComment($commentId);

    $data = array(
        'string' => OW::getLanguage()->text('blogs', 'comment_notification_string',
            array(
                'actor' => $actor['name'],
                'actorUrl' => $actor['url'],
                'title' => $post->getTitle(),
                'url' => OW::getRouter()->urlForRoute('post', array('id' => $post->getId()))
            )
        ),
        'content' => $comment->getMessage(),
        'commentId' => (int) $comment->getId()
    );

    $event = new OW_Event('base.notify', array(
            'plugin' => 'blogs',
            'action' => 'blogs-add_comment',
            'userId' => $ownerId,
            'string' => $data['string'],
            'content' => $data['content'],
            'url' => OW::getRouter()->urlForRoute('post', array('id' => $post->getId())),
            'avatar' => BOL_AvatarService::getInstance()->getAvatarUrl($userId),
        ));

    OW::getEventManager()->trigger($event);
}
OW::getEventManager()->bind('base_add_comment', 'blogs_on_notify');

function blogs_on_post_comment_add( OW_Event $event )
{
    $params = $event->getParams();

    if ( !OW::getPluginManager()->isPluginActive('activity') || empty($params['entityType']) || $params['entityType'] !== 'blog-post' )
        return;

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = $params['commentId'];

    $service = ACTIVITY_BOL_Service::getInstance();

    $postService = PostService::getInstance();

    $post = $postService->findById($entityId);

    $title = $post->getTitle();

    $action = new ACTIVITY_BOL_Action();

    $actor = array(
        'name' => BOL_UserService::getInstance()->getDisplayName($userId),
        'url' => BOL_UserService::getInstance()->getUserUrl($userId)
    );

    $owner = array(
        'name' => BOL_UserService::getInstance()->getDisplayName($post->getAuthorId()),
        'url' => BOL_UserService::getInstance()->getUserUrl($post->getAuthorId())
    );

    $comment = BOL_CommentService::getInstance()->findComment($commentId);

    $data = array(
        'string' => OW::getLanguage()->text('blogs', 'comment_activity_string',
            array(
                'actor' => $actor['name'],
                'actorUrl' => $actor['url'],
                'owner' => $owner['name'],
                'ownerUrl' => $owner['url'],
                'title' => $post->getTitle(),
                'url' => OW::getRouter()->urlForRoute('post', array('id' => $post->getId()))
            )
        ),
        'content_comment' => ( mb_strlen($comment->getMessage()) > 30 ) ? nl2br(mb_substr($comment->getMessage(), 0, 30)) . '...' : $comment->getMessage(),
        'commentId' => (int) $comment->getId()
    );

    $action->setType('blog-post-comment')
        ->setEntityId($entityId)
        ->setUserId($userId)
        ->setData($data)
        ->setTimestamp(time())
        ->setStatus('active');

    $service->addAction($action);
}
OW::getEventManager()->bind('base_add_comment', 'blogs_on_post_comment_add');

function blogs_on_post_comment_delete( OW_Event $event )
{
    $params = $event->getParams();

    if ( !OW::getPluginManager()->isPluginActive('activity') || empty($params['entityType']) || $params['entityType'] !== 'blog-post' )
        return;

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = (int) $params['commentId'];

    $service = ACTIVITY_BOL_Service::getInstance();

    $service->deleteAction($userId, 'blog-post-comment', $entityId, array('commentId' => $commentId));
}
OW::getEventManager()->bind('base_delete_comment', 'blogs_on_post_comment_delete');

function blogs_on_user_delete( OW_Event $event )
{
    $params = $event->getParams();

    if ( empty($params['deleteContent']) )
    {
        return;
    }

    $userId = $params['userId'];

    $service = PostService::getInstance();

    $count = (int) $service->countUserPost($userId);

    if ( $count == 0 )
    {
        return;
    }

    $list = $service->findUserPostList($userId, 0, $count);

    foreach ( $list as $post )
    {
        $service->delete($post);
    }
}
OW::getEventManager()->bind(OW_EventManager::ON_USER_UNREGISTER, 'blogs_on_user_delete');

//BOL_MediaPanelService::getInstance()->deleteImages('blogs', 10);
?>