<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

$plugin = OW::getPluginManager()->getPlugin('links');

$key = strtoupper($plugin->getKey());

OW::getAutoloader()->addClass('Link', $plugin->getBolDir() . 'dto' . DS . 'link.php');
OW::getAutoloader()->addClass('LinkDao', $plugin->getBolDir() . 'dao' . DS . 'link_dao.php');
OW::getAutoloader()->addClass('LinkService', $plugin->getBolDir() . 'service' . DS . 'link_service.php');

OW::getRouter()->addRoute(new OW_Route('links', 'links', "{$key}_CTRL_List", 'index'));
OW::getRouter()->addRoute(new OW_Route('link', 'link/:id', "{$key}_CTRL_View", 'index'));

OW::getRouter()->addRoute(new OW_Route('link-save-new', 'links/new', "{$key}_CTRL_Save", 'index'));
OW::getRouter()->addRoute(new OW_Route('link-save-edit', 'links/edit/:id', "{$key}_CTRL_Save", 'index'));

OW::getRouter()->addRoute(new OW_Route('links-latest', 'links/latest', "{$key}_CTRL_List", 'index'));
OW::getRouter()->addRoute(new OW_Route('links-most-discussed', 'links/most-discussed', "{$key}_CTRL_List", 'index'));
OW::getRouter()->addRoute(new OW_Route('links-top-rated', 'links/top-rated', "{$key}_CTRL_List", 'index'));
OW::getRouter()->addRoute(new OW_Route('links-by-tag', 'links/browse-by-tag/', "{$key}_CTRL_List", 'index'));

OW::getRouter()->addRoute(new OW_Route('links-admin', 'admin/links', "{$key}_CTRL_Admin", 'index'));

OW::getRegistry()->addToArray(BASE_CMP_AddNewContent::REGISTRY_DATA_KEY,
    array(
        BASE_CMP_AddNewContent::DATA_KEY_ICON_CLASS => 'ow_ic_link',
        BASE_CMP_AddNewContent::DATA_KEY_URL => OW::getRouter()->urlForRoute('link-save-new'),
        BASE_CMP_AddNewContent::DATA_KEY_LABEL => OW::getLanguage()->text($plugin->getKey(), 'add_new_link'))
);

function links_on_user_delete( OW_Event $event )
{
    $params = $event->getParams();

    if ( empty($params['deleteContent']) )
    {
        return;
    }

    $userId = $params['userId'];

    $service = LinkService::getInstance();


    $count = (int) $service->countUserLinks($userId);

    if ( $count == 0 )
    {
        return;
    }

    $list = $service->findUserLinkList($userId, 0, $count);

    foreach ( $list as $link )
    {
        $service->delete($link);
    }
}
OW::getEventManager()->bind(OW_EventManager::ON_USER_UNREGISTER, 'links_on_user_delete');

function links_on_post_comment_add( OW_Event $event )
{
    $params = $event->getParams();

    if ( !OW::getPluginManager()->isPluginActive('activity') || empty($params['entityType']) || $params['entityType'] !== 'link' )
        return;

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = $params['commentId'];

    $service = ACTIVITY_BOL_Service::getInstance();

    $linkService = LinkService::getInstance();

    $link = $linkService->findById($entityId);

    $title = $link->getTitle();

    $action = new ACTIVITY_BOL_Action();

    $actor = array(
        'name' => BOL_UserService::getInstance()->getDisplayName($userId),
        'url' => BOL_UserService::getInstance()->getUserUrl($userId)
    );

    $owner = array(
        'name' => BOL_UserService::getInstance()->getDisplayName($link->getUserId()),
        'url' => BOL_UserService::getInstance()->getUserUrl($link->getUserId())
    );

    $comment = BOL_CommentService::getInstance()->findComment($commentId);

    $data = array(
        'string' => OW::getLanguage()->text('links', 'comment_activity_string',
            array(
                'actor' => $actor['name'],
                'actorUrl' => $actor['url'],
                'owner' => $owner['name'],
                'ownerUrl' => $owner['url'],
                'title' => $link->getTitle(),
                'url' => OW::getRouter()->urlForRoute('link', array('id' => $link->getId()))
            )
        ),
        'content_comment' => ( mb_strlen($comment->getMessage()) > 30 ) ? nl2br(mb_substr($comment->getMessage(), 0, 30)) . '...' : $comment->getMessage(),
        'commentId' => (int) $comment->getId()
    );

    $action->setType('link-comment')
        ->setEntityId($entityId)
        ->setUserId($userId)
        ->setData($data)
        ->setTimestamp(time())
        ->setStatus('active');

    $service->addAction($action);
}
OW::getEventManager()->bind('base_add_comment', 'links_on_post_comment_add');

function links_on_link_comment_delete( OW_Event $event )
{
    $params = $event->getParams();

    if ( !OW::getPluginManager()->isPluginActive('activity') || empty($params['entityType']) || $params['entityType'] !== 'link' )
        return;

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = (int) $params['commentId'];

    $service = ACTIVITY_BOL_Service::getInstance();

    $service->deleteAction($userId, 'link-comment', $entityId, array('commentId' => $commentId));
}
OW::getEventManager()->bind('base_delete_comment', 'links_on_link_comment_delete');

function links_on_notify_actions( BASE_EventCollector $e )
{
    $e->add(array(
        'section' => 'links',
        'action' => 'links-add_comment',
        'sectionLabel' => 'Links',
        'description' => OW::getLanguage()->text('links', 'email_notifications_setting_comment'),
        'selected' => 1,
        'sectionIcon' => 'ow_ic_write'
    ));
}
OW::getEventManager()->bind('base.notify_actions', 'links_on_notify_actions');

function links_notify_on_post_comment_add( OW_Event $event )
{
    $params = $event->getParams();

    if ( empty($params['entityType']) || $params['entityType'] !== 'link' )
        return;

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = $params['commentId'];

    $service = ACTIVITY_BOL_Service::getInstance();

    $linkService = LinkService::getInstance();

    $link = $linkService->findById($entityId);

    $title = $link->getTitle();

    $action = new ACTIVITY_BOL_Action();

    $actor = array(
        'name' => BOL_UserService::getInstance()->getDisplayName($userId),
        'url' => BOL_UserService::getInstance()->getUserUrl($userId),
        'avatar-url' => BOL_AvatarService::getInstance()->getAvatarUrl($userId),
    );

    $comment = BOL_CommentService::getInstance()->findComment($commentId);

    $data = array(
        'string' => OW::getLanguage()->text('links', 'comment_notification_string',
            array(
                'actor' => $actor['name'],
                'actorUrl' => $actor['url'],
                'title' => $link->getTitle(),
                'url' => OW::getRouter()->urlForRoute('link', array('id' => $link->getId()))
            )
        ),
        'content' => ( mb_strlen($comment->getMessage()) > 30 ) ? nl2br(mb_substr($comment->getMessage(), 0, 30)) . '...' : $comment->getMessage(),
        'commentId' => (int) $comment->getId(),
        'avatar' => $actor['avatar-url']
    );

    $event = new OW_Event('base.notify', array(
            'plugin' => 'links',
            'action' => 'liks-add_comment',
            'userId' => $link->getUserId(),
            'string' => $data['string'],
            'content' => $data['content'],
            'url' => OW::getRouter()->urlForRoute('link', array('id' => $link->getId())),
            'avatar' => BOL_AvatarService::getInstance()->getAvatarUrl($userId),
        ));

    OW::getEventManager()->trigger($event);
}
OW::getEventManager()->bind('base_add_comment', 'links_notify_on_post_comment_add');
?>
