<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * New conversation form class
 *
 * @author Podyachev Evgeny <joker.OW2@gmail.com>
 * @package ow_plugin.mailbox.classes
 * @since 1.0
 */

class CreateConversationForm extends Form
{
    /**
     * Class constructor
     *
     */

    public function __construct($interlocutorId)
    {
        $language = OW::getLanguage();
        
        parent::__construct('mailbox-create-conversation-form');

        $this->setId('mailbox-create-conversation-form');
        $this->setAjax();

        $hidden = new HiddenField('userId');
        $hidden->setValue($interlocutorId);
        $this->addElement($hidden);

        //thickbox
        $subject = new TextField('subject');
        $subject->setLabel($language->text('mailbox', 'subject'))->addAttribute('class', 'ow_text');
        $subject->addValidator(new StringValidator(0, 2048));
        $subject->setRequired(true);
        $this->addElement($subject);

        $message = new Textarea('message');
        $message->setLabel($language->text('mailbox', 'text'))->addAttribute('class', 'ow_text');
        $message->addAttribute('rows', '10');
        $message->addValidator(new StringValidator(0, 24000));
        $message->setRequired(true);
        $this->addElement($message);

        $submit = new Submit('send');
        $submit->setValue($language->text('mailbox', 'send_button'));
        $submit->addAttribute('class', 'ow_button ow_ic_mail');
        $this->addElement($submit);
        
        if ( !OW::getRequest()->isAjax() )
        {
            $messageError = $language->text('mailbox', 'create_conversation_fail_message');
            $messageSuccess = $language->text('mailbox', 'create_conversation_message');
            
            $js = " owForms['mailbox-create-conversation-form'].bind( 'success',
            function( json )
            {

                if ( json.result == 'permission_denied' )
                {
                    OW.error('".OW::getLanguage()->text('mailbox', 'write_permission_denied')."');
                }
            	else if( json.result == true )
            	{
            	    $('#TB_closeWindowButton').click();
            	    OW.info('{$messageSuccess}');
                }
                else
                {
                    OW.error('{$messageError}');
                }

                $('#mailbox-create-conversation-form input[name=userId]').val(" . $interlocutorId . ");

        	} ); ";

            OW::getDocument()->addOnloadScript( $js );
        }
    }

    /**
     * Creates new conversation
     *
     * @param int $initiatorId
     * @param int $interlocutorId
     */

    public function process( $initiatorId, $interlocutorId )
    {
        if ( OW::getRequest()->isAjax() )
        {
            if ( empty($initiatorId) || empty($interlocutorId) )
            {
                echo json_encode(array('result'=> false ));
                exit();
            }

            $isAuthorized = OW::getUser()->isAuthorized( 'mailbox', 'send_message' );
            if( !$isAuthorized )
            {
                echo json_encode(array('result'=> 'permission_denied' ));
                exit();
            }

            $values = $this->getValues();
            $conversationService = MAILBOX_BOL_ConversationService::getInstance();
            $conversationService->createConversation($initiatorId, $interlocutorId, htmlspecialchars($values['subject']), htmlspecialchars($values['message']));
            
            echo json_encode(array('result'=> true ));
            exit();
        }
    }
}