<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is
 * licensed under The BSD license.

 * ---
 * Copyright (c) 2009, Skalfa LLC
 * All rights reserved.

 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the
 * following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice, this list of conditions and
 *  the following disclaimer.
 *
 *  - Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
 *  the following disclaimer in the documentation and/or other materials provided with the distribution.
 *
 *  - Neither the name of the Skalfa LLC nor the names of its contributors may be used to endorse or promote products
 *  derived from this software without specific prior written permission.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
$plugin = OW::getPluginManager()->getPlugin('video');

$classesToAutoload = array(
    'VideoProviders' => $plugin->getRootDir() . 'classes' . DS . 'video_providers.php'
);

OW::getAutoloader()->addClassArray($classesToAutoload);

OW::getRouter()->addRoute(
    new OW_Route(
        'video_view_list',
        'video/viewlist/:listType/',
        'VIDEO_CTRL_Video',
        'viewList',
        array('listType' => array('default' => 'latest'))
    )
);

OW::getRouter()->addRoute(new OW_Route('video_list_index', 'video/', 'VIDEO_CTRL_Video', 'viewList'));

OW::getRouter()->addRoute(new OW_Route('view_clip', 'video/view/:id/', 'VIDEO_CTRL_Video', 'view'));
OW::getRouter()->addRoute(new OW_Route('edit_clip', 'video/edit/:id/', 'VIDEO_CTRL_Video', 'edit'));
OW::getRouter()->addRoute(new OW_Route('view_list', 'video/viewlist/:listType/', 'VIDEO_CTRL_Video', 'viewList'));
OW::getRouter()->addRoute(new OW_Route('view_tagged_list_st', 'video/viewlist/tagged/', 'VIDEO_CTRL_Video', 'viewTaggedList'));
OW::getRouter()->addRoute(new OW_Route('view_tagged_list', 'video/viewlist/tagged/:tag', 'VIDEO_CTRL_Video', 'viewTaggedList'));
OW::getRouter()->addRoute(new OW_Route('video_user_video_list', 'video/user-video/:user', 'VIDEO_CTRL_Video', 'viewUserVideoList'));

OW::getRouter()->addRoute(new OW_Route('video_admin_config', 'admin/video/', 'VIDEO_CTRL_Admin', 'index'));

OW::getThemeManager()->addDecorator('video_list_item', $plugin->getKey());

//OW::getNavigation()->addMenuItem(OW_Navigation::ADMIN_PLUGINS, 'video_admin_config', 'admin', 'sidebar_menu_item_plugin_video');

OW::getRegistry()->addToArray(BASE_CMP_AddNewContent::REGISTRY_DATA_KEY,
    array(
        BASE_CMP_AddNewContent::DATA_KEY_ICON_CLASS => 'ow_ic_video',
        BASE_CMP_AddNewContent::DATA_KEY_URL => OW::getRouter()->urlFor('VIDEO_CTRL_Add', 'index'),
        BASE_CMP_AddNewContent::DATA_KEY_LABEL => OW::getLanguage()->text('video', 'video')
));

function video_delete_user_content( OW_Event $event )
{
    $params = $event->getParams();

    if ( !isset($params['deleteContent']) || !(bool) $params['deleteContent'] )
    {
        return;
    }

    $userId = (int) $params['userId'];

    if ( $userId > 0 )
    {
        VIDEO_BOL_ClipService::getInstance()->deleteUserClips($userId);
    }
}
OW::getEventManager()->bind(OW_EventManager::ON_USER_UNREGISTER, 'video_delete_user_content');

function video_add_comment_activity( OW_Event $event )
{
    $params = $event->getParams();

    if ( !OW::getPluginManager()->isPluginActive('activity')
        || empty($params['entityType'])
        || $params['entityType'] !== 'video_comments' )
    {
        return;
    }

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = $params['commentId'];

    $activityService = ACTIVITY_BOL_Service::getInstance();
    $clipService = VIDEO_BOL_ClipService::getInstance();
    $userService = BOL_UserService::getInstance();

    $clip = $clipService->findClipById($entityId);

    $action = new ACTIVITY_BOL_Action();

    $comment = BOL_CommentService::getInstance()->findComment($commentId);

    $data = array(
        'string' => OW::getLanguage()->text('video', 'comment_activity_string',
            array(
                'commentor' => $userService->getDisplayName($userId),
                'commentorUrl' => $userService->getUserUrl($userId),
                'owner' => $userService->getDisplayName($clip->getUserId()),
                'ownerUrl' => $userService->getUserUrl($clip->getUserId()),
                'title' => $clip->title,
                'url' => OW::getRouter()->urlForRoute('view_clip', array('id' => $entityId))
            )
        ),
        'content_comment' => (mb_strlen($comment->getMessage()) > 30) ? nl2br(mb_substr($comment->getMessage(), 0, 30)) . '...' : $comment->getMessage(),
        'commentId' => (int) $commentId
    );

    $action->setType('video-comment')
        ->setEntityId($entityId)
        ->setUserId($userId)
        ->setData($data)
        ->setTimestamp(time())
        ->setStatus('active');

    $activityService->addAction($action);
}
OW::getEventManager()->bind('base_add_comment', 'video_add_comment_activity');

function video_on_notify_actions( BASE_EventCollector $e )
{
    $e->add(array(
        'section' => 'video',
        'action' => 'video-add_comment',
        'description' => OW::getLanguage()->text('video', 'email_notifications_setting_comment'),
        'sectionIcon' => 'ow_ic_video',
        'sectionLabel' => OW::getLanguage()->text('video', 'email_notifications_section_label'),
        'selected' => true
    ));
}
OW::getEventManager()->bind('base.notify_actions', 'video_on_notify_actions');

function video_add_comment_notification( OW_Event $event )
{
    $params = $event->getParams();

    if ( empty($params['entityType']) || $params['entityType'] !== 'video_comments' )
    {
        return;
    }

    $entityId = $params['entityId'];
    $userId = $params['userId'];
    $commentId = $params['commentId'];

    $clipService = VIDEO_BOL_ClipService::getInstance();
    $userService = BOL_UserService::getInstance();

    $clip = $clipService->findClipById($entityId);

    if ( $clip->userId != $userId )
    {
        $comment = BOL_CommentService::getInstance()->findComment($commentId);
        $url = OW::getRouter()->urlForRoute('view_clip', array('id' => $entityId));

        $event = new OW_Event('base.notify', array(
                'plugin' => 'video',
                'pluginIcon' => 'ow_ic_video',
                'action' => 'video-add_comment',
                'userId' => $clip->userId,
                'string' => OW::getLanguage()->text('video', 'email_notifications_comment', array(
                    'userName' => $userService->getDisplayName($userId),
                    'userUrl' => $userService->getUserUrl($userId),
                    'videoUrl' => $url,
                    'videoTitle' => strip_tags($clip->title)
                )),
                'content' => $comment->getMessage(),
                'url' => $url
            ));

        OW::getEventManager()->trigger($event);
    }
}
OW::getEventManager()->bind('base_add_comment', 'video_add_comment_notification');