<?php

/**
 * EXHIBIT A. Common Public Attribution License Version 1.0
 * The contents of this file are subject to the Common Public Attribution License Version 1.0 (the “License”);
 * you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.oxwall.org/license.php. The License is based on the Mozilla Public License Version 1.1
 * but Sections 14 and 15 have been added to cover use of software over a computer network and provide for
 * limited attribution for the Original Developer. In addition, Exhibit A has been modified to be consistent
 * with Exhibit B. Software distributed under the License is distributed on an “AS IS” basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the specific language
 * governing rights and limitations under the License. The Original Code is Oxwall software.
 * The Initial Developer of the Original Code is Skalfa LLC (http://www.skalfa.com/).
 * All portions of the code written by Skalfa LLC are Copyright (c) 2009. All Rights Reserved.

 * EXHIBIT B. Attribution Information
 * Attribution Copyright Notice: Copyright 2009 Skalfa LLC. All rights reserved.
 * Attribution Phrase (not exceeding 10 words): Powered by Oxwall community software
 * Attribution URL: http://www.oxwall.org/
 * Graphic Image as provided in the Covered Code.
 * Display of Attribution Information is required in Larger Works which are defined in the CPAL as a work
 * which combines Covered Code or portions thereof with code not governed by the terms of the CPAL.
 */
class BASE_CMP_Comments extends OW_Component
{
    /**
     * Constructor.
     * 
     * @param string $entityType
     * @param integer $entityId
     * @param integer $ownerId
     * @param integer $displayType
     */
    public function __construct( BASE_CommentsParams $params )
    {
        parent::__construct();

        $commentService = BOL_CommentService::getInstance();
        $language = OW::getLanguage();

        $this->assign('displayType', $params->getDisplayType());

        $id = rand(1, 1000000);

        $cmpContextId = "comments-$id";

        $formName = "comment-add-$id";

        $this->assign('cmpContext', $cmpContextId);

        OW::getDocument()->addScript(OW::getPluginManager()->getPlugin('base')->getStaticJsUrl() . 'comments.js');

        if ( OW::getUser()->isAuthorized($params->getPluginKey(), 'add_comment') && $params->getAddComment() )
        {
            //comment form
            $form = new Form($formName);

            $textArea = new Textarea('commentText');
            $textArea->setHasInvitation(true);
            $validator = new RequiredValidator();
            $validator->setErrorMessage($language->text('base', 'comment_required_validator_message'));
            $textArea->addValidator($validator);
            $form->addElement($textArea);

            $entityTypeField = new HiddenField('entityType');
            $entityTypeField->setValue($params->getEntityType());
            $form->addElement($entityTypeField);

            $entityIdField = new HiddenField('entityId');
            $entityIdField->setValue($params->getEntityId());
            $form->addElement($entityIdField);

            $displayTypeField = new HiddenField('displayType');
            $displayTypeField->setValue($params->getDisplayType());
            $form->addElement($displayTypeField);

            $pluginKeyField = new HiddenField('pluginKey');
            $pluginKeyField->setValue($params->getPluginKey());
            $form->addElement($pluginKeyField);

            $ownerIdField = new HiddenField('ownerId');
            $ownerIdField->setValue($params->getOwnerId());
            $form->addElement($ownerIdField);

            $commentsOnPageField = new HiddenField('commentCountOnPage');
            $commentsOnPageField->setValue($params->getCommentCountOnPage());
            $form->addElement($commentsOnPageField);

            $submit = new Submit('comment-submit');
            $submit->setValue($language->text('base', 'comment_add_submit_label'));
            $form->addElement($submit);

            $form->setAjax(true);
            $form->setAction(OW::getRouter()->urlFor('BASE_CTRL_Comments', 'addComment'));
            $this->addForm($form);

            $this->assign('id', $id);

            OW::getDocument()->addOnloadScript(
                "var commentsForm$id = new OwComments('$cmpContextId', '$formName');
                owForms['{$form->getName()}'].bind('success', function(data){commentsForm$id.repaintCommentsList(data);});
                owForms['{$form->getName()}'].reset = false;"
            );

            $this->assign('form', true);
        }
        else
        {


            $this->assign('authErrorMessage', OW::getLanguage()->text('base',
                    ( OW::getUser()->isAuthenticated() ) ? 'comments_add_auth_message' : 'comments_add_login_message'
                )
            );
        }

        // add comment list cmp
        $this->addComponent('commentList', new BASE_CMP_CommentsList($params));
    }
}

final class BASE_CommentsParams
{
    const DISPLAY_TYPE_BOTTOM_FORM_WITH_FULL_LIST = 1;
    const DISPLAY_TYPE_TOP_FORM_WITH_PAGING = 2;

    private $pluginKey;
    private $entityType;
    private $entityId;
    private $ownerId;
    private $displayType;
    private $commentCountOnPage;
    private $addComment;

    public function __construct( $pluginKey, $entityType )
    {
        $this->pluginKey = trim($pluginKey);
        $this->entityType = trim($entityType);
        $this->entityId = 1;
        $this->displayType = self::DISPLAY_TYPE_TOP_FORM_WITH_PAGING;
        $this->addComment = true;
    }

    public function getPluginKey()
    {
        return $this->pluginKey;
    }

    public function getEntityType()
    {
        return $this->entityType;
    }

    public function getEntityId()
    {
        return $this->entityId;
    }

    public function setEntityId( $entityId )
    {
        $this->entityId = (int) $entityId;

        return $this;
    }

    public function getOwnerId()
    {
        return $this->ownerId;
    }

    public function setOwnerId( $ownerId )
    {
        $this->ownerId = (int) $ownerId;

        return $this;
    }

    public function getDisplayType()
    {
        return $this->displayType;
    }

    public function setDisplayType( $displayType )
    {
        $this->displayType = ((int) $displayType === self::DISPLAY_TYPE_BOTTOM_FORM_WITH_FULL_LIST ) ? self::DISPLAY_TYPE_BOTTOM_FORM_WITH_FULL_LIST : self::DISPLAY_TYPE_TOP_FORM_WITH_PAGING;

        return $this;
    }

    public function getCommentCountOnPage()
    {
        return $this->commentCountOnPage;
    }

    public function setCommentCountOnPage( $commentCountOnPage )
    {
        $this->commentCountOnPage = (int) $commentCountOnPage;

        return $this;
    }

    public function getAddComment()
    {
        return $this->addComment;
    }

    public function setAddComment( $addComment )
    {
        $this->addComment = (bool) $addComment;
        return $this;
    }
}