<?php

/**
 * EXHIBIT A. Common Public Attribution License Version 1.0
 * The contents of this file are subject to the Common Public Attribution License Version 1.0 (the “License”);
 * you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.oxwall.org/license.php. The License is based on the Mozilla Public License Version 1.1
 * but Sections 14 and 15 have been added to cover use of software over a computer network and provide for
 * limited attribution for the Original Developer. In addition, Exhibit A has been modified to be consistent
 * with Exhibit B. Software distributed under the License is distributed on an “AS IS” basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the specific language
 * governing rights and limitations under the License. The Original Code is Oxwall software.
 * The Initial Developer of the Original Code is Skalfa LLC (http://www.skalfa.com/).
 * All portions of the code written by Skalfa LLC are Copyright (c) 2009. All Rights Reserved.

 * EXHIBIT B. Attribution Information
 * Attribution Copyright Notice: Copyright 2009 Skalfa LLC. All rights reserved.
 * Attribution Phrase (not exceeding 10 words): Powered by Oxwall community software
 * Attribution URL: http://www.oxwall.org/
 * Graphic Image as provided in the Covered Code.
 * Display of Attribution Information is required in Larger Works which are defined in the CPAL as a work
 * which combines Covered Code or portions thereof with code not governed by the terms of the CPAL.
 */

/**
 * Text Formatter Component
 *
 * @author Aybat Duyshokov <duyshokov@gmail.com>
 * @package ow_system_plugins.base.components
 * @since 1.0
 */
class BASE_CMP_TextFormatter extends OW_Component
{

    function __construct( $plugin, $elId, $dl, $dr, $controls, $template = null )
    {
        parent::__construct();

        if ( $dl == '[' && $dr == ']' )
        {
            $this->assign('bb', 'true');
        }
        else
        {
            $this->assign('bb', 'false');
        }

        $this->assign('elId', $elId);

        if ( $template == null )
        {
            $this->setTemplate(OW::getPluginManager()->getPlugin('base')->getCmpViewDir() . 'text_formatter.html');
        }

        $this->assign('plugin', $plugin);

        OW::getDocument()->addScript(OW::getPluginManager()->getPlugin('base')->getStaticJsUrl() . 'jquery-fieldselection.js');

        $tid = $elId;

        $js = '$(function(){';

        $mlist = array('image');

        $this->assign('mlist', $mlist);

        foreach ( $controls as $ctrl )
        {
            $isPaired = !(isset($ctrl['isPaired']) && $ctrl['isPaired'] == false) ? 1 : 0;

            if ( $ctrl['id'] == 'lid' )
            {
                $js .= "
	$('#{$ctrl['id']}').click(function(){

		var open = '{$ctrl['open']}', close = '{$dl}/a$dr';

		var s = $('#{$tid}').getSelection();

		var s2 = $('#{$tid}').val();

		if(s.text.length == 0){
			if(typeof(this.closed) == 'undefined' || this.closed == true){
				this.url = prompt('{$ctrl['extra']['#url#']['inv']}', '{$ctrl['extra']['#url#']['def']}');
				
				if(!this.url) return;
				
				$(this).html('/'+$(this).html());

				this.closed = false;
				$('#{$tid}').val( s2.substr(0, s.start) + open.replace('#url#', this.url) +  s2.substr(s.end, s2.length-1 ));
				setCaretPosition('{$tid}', s.start+open.replace('#url#', this.url).length + s.text.length);
			}
			else{

				$('#{$tid}').val( s2.substr(0, s.start) + close +  s2.substr(s.end, s2.length-1 ));
				setCaretPosition('{$tid}', s.start+close.length);
				var v = $(this).html().toString();
				$(this).html( v.substr( 1, v.length) );

				this.closed = !this.closed;
			}

			return;
		}

		this.url = prompt('{$ctrl['extra']['#url#']['inv']}', '{$ctrl['extra']['#url#']['def']}');

		if(!this.url) return;
		
		var r =  s2.substr(0, s.start) + open.replace('#url#', this.url) + s.text + close +  s2.substr(s.end, s2.length-1 );

		$('#{$tid}').val(r);

		setCaretPosition('{$tid}', s.start+open.replace('#url#', this.url).length + s.text.length + close.length);

		$('#{$tid}').trigger('keydown');

	});					
					";
                continue;
            };

            $ctrl['close'] = empty($ctrl['close']) ? '' : $ctrl['close'];

            $js.="
					$('#{$ctrl['id']}').click( function(){
						var open = '{$ctrl['open']}', close  = '{$ctrl['close']}';

						var s = $('#{$tid}').getSelection();

						var s2 = $('#{$tid}').val();
						
						if(s.text.length == 0 || !{$isPaired}){
							if(typeof(this.closed) == 'undefined' || this.closed == true){
								$('#{$tid}').val( s2.substr(0, s.start) + open + s2.substr(s.end, s2.length-1) );

								setCaretPosition('{$tid}', s.start+open.length);

								if({$isPaired}){
									this.closed = false;
									$(this).html('/'+$(this).html());
								}
							}
							else{

								$('#{$tid}').val( s2.substr(0, s.start) + close + s2.substr(s.end, s2.length-1) );

								var v = $(this).html().toString();
								$(this).html( v.substr( 1, v.length) );
								setCaretPosition('{$tid}', s.start+close.length)
								this.closed = !this.closed;
							}

							return;
						}

						var r =  s2.substr(0, s.start) + open + s.text + close +  s2.substr(s.end, s2.length-1 );
				
						$('#{$tid}').val(r);
						setCaretPosition('{$tid}', s.start+open.length + s.text.length + close.length);
						$('#{$tid}').trigger('keydown');						
					});
				";
        }

        $js .= '});';

        OW::getDocument()->addOnloadScript($js, 100);

        $this->assign('controls', $controls);
        $this->assign('tid', $tid);


        OW::getDocument()->addScriptDeclaration("
			function getRangeObject(selectionObject) {
				if (selectionObject.getRangeAt)
					return selectionObject.getRangeAt(0);
				else { // Safari!
					var range = document.createRange();
					range.setStart(selectionObject.anchorNode,selectionObject.anchorOffset);
					range.setEnd(selectionObject.focusNode,selectionObject.focusOffset);
					return range;
				}
			}

			function setCaretPosition(elemId, caretPos) {
			    var elem = document.getElementById(elemId);
			    elem.focus();
			    elem.setSelectionRange(caretPos, caretPos);
			}		
		");
    }

    public static function fromBBtoHtml( $txt )
    {
        return mb_ereg_replace('\\[(.*?)\\]', '<\\1>', $txt);
    }

    public static function fromHtmltoBB( $txt )
    {
        return mb_ereg_replace('\\<(.*?)\\>', '[\\1]', $txt);
    }
}