<?php

/**
 * EXHIBIT A. Common Public Attribution License Version 1.0
 * The contents of this file are subject to the Common Public Attribution License Version 1.0 (the “License”);
 * you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.oxwall.org/license.php. The License is based on the Mozilla Public License Version 1.1
 * but Sections 14 and 15 have been added to cover use of software over a computer network and provide for
 * limited attribution for the Original Developer. In addition, Exhibit A has been modified to be consistent
 * with Exhibit B. Software distributed under the License is distributed on an “AS IS” basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for the specific language
 * governing rights and limitations under the License. The Original Code is Oxwall software.
 * The Initial Developer of the Original Code is Skalfa LLC (http://www.skalfa.com/).
 * All portions of the code written by Skalfa LLC are Copyright (c) 2009. All Rights Reserved.

 * EXHIBIT B. Attribution Information
 * Attribution Copyright Notice: Copyright 2009 Skalfa LLC. All rights reserved.
 * Attribution Phrase (not exceeding 10 words): Powered by Oxwall community software
 * Attribution URL: http://www.oxwall.org/
 * Graphic Image as provided in the Covered Code.
 * Display of Attribution Information is required in Larger Works which are defined in the CPAL as a work
 * which combines Covered Code or portions thereof with code not governed by the terms of the CPAL.
 */

/**
 * @author Sardar Madumarov <madumarov@gmail.com>
 * @package ow_utilities
 * @since 1.0
 */
class UTIL_HtmlTag
{
    /**
     * Generates and returns HTML tag code.
     *
     * @param string $tag
     * @param array $attrs
     * @param boolean $pair
     * @param string $content
     * @return string
     */
    public static function generateTag( $tag, $attrs = null, $pair = false, $content = null )
    {
        $attrString = '';
        if ( $attrs !== null && !empty($attrs) )
        {
            foreach ( $attrs as $key => $value )
            {
                $attrString .= ' ' . $key . '="' . $value . '"';
            }
        }

        return $pair ? '<' . $tag . $attrString . '>' . ( $content === null ? '' : $content ) . '</' . $tag . '>' : '<' . $tag . $attrString . ' />';
    }

    /**
     * Generates randow ID for HTML tags.
     *
     * @param string $prefix
     * @return string
     */
    public static function generateAutoId( $prefix = null )
    {
        $prefix = ( $prefix === null ) ? 'auto_id' : trim($prefix);

        return $prefix . '-' . rand(1, 1000000);
    }
    /**
     * @var HTMLPurifier
     */
    private static $htmlPurifier;
    /**
     * @var array
     */
    private static $configInstances = array();

    /**
     * Removes all restricted HTML tags and attributes. Works with white list.
     * If allowed lists are empty default filtration strategy used.
     *
     * @param string $text
     * @param array $allowedTagList
     * @param array $allowedAttributeList
     * @param boolean $nlToBr
     * @return string
     */
    public static function stripTags( $text, array $allowedTagList = null, array $allowedAttributeList = null, $nlToBr = true )
    {
        $key = json_encode(array($allowedTagList, $allowedAttributeList, $nlToBr));

        if ( self::$htmlPurifier === null )
        {
            require_once OW_DIR_LIB . 'html_purifier' . DS . 'HTMLPurifier.auto.php';
            self::$htmlPurifier = new HTMLPurifier();
        }

        if ( !array_key_exists($key, self::$configInstances) )
        {
            $config = HTMLPurifier_Config::createDefault();

            if ( !empty($allowedTagList) )
            {
                $config->set('HTML.AllowedElements', $allowedTagList);
            }

            $config->set('Cache.DefinitionImpl', null);

            self::$configInstances[$key] = $config;

            if ( !empty($allowedAttributeList) )
            {
                $attrsToAdd = array();

                foreach ( $allowedAttributeList as $value )
                {
                    if ( strstr($value, '.') )
                    {
                        $attrsToAdd[] = trim($value);
                    }
                    else
                    {
                        $attrsToAdd[] = '*.' . trim($value);
                    }
                }

                $config->set('HTML.AllowedAttributes', $attrsToAdd);

//                $config->set('HTML.SafeEmbed', true);
//                $config->set('Output.FlashCompat', true);
//                $config->set('HTML.SafeObject', true);
//                $def = $config->getHTMLDefinition(true);
            }
        }

        if ( $nlToBr )
        {
            $text = nl2br($text);
        }

        return self::$htmlPurifier->purify($text, self::$configInstances[$key]);
    }

     /**
     * Removes all restricted HTML tags and attributes. Works with white list.
     * If allowed lists are empty default filtration strategy used.
     *
     * @param string $text
     * @param array $allowedTagList
     * @param array $allowedAttributeList
     * @param boolean $nlToBr
     * @return string
     */
    public static function stripJs( $text )
    {
       $attrs = array(
            'onchange',
            'onclick' ,
            'ondblclick',
            'onerror' ,
            'onfocus' ,
            'onkeydown' ,
            'onkeypress',
            'onkeyup' ,
            'onload'  ,
            'onmousedown',
            'onmousemove',
            'onmouseout',
            'onmouseover',
            'onmouseup' ,
            'onreset' ,
            'onselect',
            'onsubmit',
            'onunload' );
        
        $text = preg_replace("/<\s*script\s*>.*?<\s*\/\s*script\s*>/i", "", $text);
        $text = preg_replace("/<(.*?)\s*javascript\s*:(.*?)>/i", "<$1javascript://$2>", $text);
        
        foreach( $attrs as $attr )
        {
            $text = preg_replace("/<(.*?)" . $attr . "(.*?)>/i", "<$1wrongAttr$2>", $text);
        }
        
        return $text;
    }
}